@@ -1,6 +1,6 @@
 use anyhow::Result;
 use miniserde::{json, Deserialize, Serialize};
-use setup::Shell;
+use setup::{verify_setup, Shell};
 use std::{
     fmt::{self, Display},
     path::{Path, PathBuf},
@@ -58,11 +58,20 @@ impl Completer {
         let text = std::fs::read_to_string(&config_path).unwrap();
         let completion_data = json::from_str::<CompletionData>(&text)?;
 
-        Ok(Completer {
+        let completer = Completer {
             shell: Shell::PowerShell,
             config_path: config_path.as_ref().to_owned(),
             completion_data,
-        })
+        };
+
+        if !verify_setup(&completer, Shell::PowerShell)? {
+            println!(
+                "warning: failed to verify a setup for {}. To setup tab completion for your CLI, add this code:\n\nlet completer = Completer::new(Path::new(\"tabby.config.json\"));\ntabby::setup::install(&completer, Shell::PowerShell);",
+                completer.completion_data.cli_name
+            );
+        }
+
+        Ok(completer)
     }
 
     pub fn from<P: AsRef<Path>>(p: P) -> Result<Completer> {
@@ -75,9 +84,11 @@ impl Completer {
 
         match self.shell {
             Shell::PowerShell => {
-                let current_word = args[1].replace("--word=", "");
-                let mut line = args[3].to_string();
-                let position = args[5].parse::<u64>().unwrap();
+                let current_word = args[2].replace("--word=", "");
+
+                let mut line = args[4].to_string();
+
+                let position = args[6].parse::<u64>().unwrap();
 
                 if position > line.len() as u64 {
                     line.push_str(" ");
