@@ -11,7 +11,7 @@ Register-ArgumentCompleter -Native -CommandName <cli-name> -ScriptBlock {
         [Console]::InputEncoding = [Console]::OutputEncoding = $OutputEncoding = [System.Text.Utf8Encoding]::new()
         $Local:word = $wordToComplete.Replace('"', '""')
         $Local:ast = $commandAst.ToString().Replace('"', '""')
-        tabby.exe --word="$Local:word" --commandline "$Local:ast" --position $cursorPosition | ForEach-Object {
+        <cli-name>.exe complete --word="$Local:word" --commandline "$Local:ast" --position $cursorPosition | ForEach-Object {
             [System.Management.Automation.CompletionResult]::new($_, $_, 'ParameterValue', $_)
         }
 }"#;
